use ui::context::Context;
use ui::color;
use widgets::{Widget, WidgetParams};

pub struct Spacer {
    context: Context,
    width: u16
}

pub fn spacer(params: WidgetParams) -> Box<Widget> {
    let mut context = params.context;
    let width = params.config.lookup("width")
        .and_then(|v| v.as_integer())
        .expect("spacer requires a width definition");
    let color = params.config.lookup("color")
        .and_then(|v| v.as_str())
        .and_then(|s| color::from_str(s))
        .expect("spacer requires a color definition");
    context.set_bg_color(color);
    let widget = Spacer {
        context: context,
        width: width as u16
    };
    Box::new(widget)
}

impl Widget for Spacer {
    fn render(&mut self, x: u16, width: u16) {
        self.context.draw_bg(x, width);
    }

    fn width(&mut self) -> u16 {
        self.width
    }
}
